@@ -11,6 +11,7 @@ from scipy import stats
 from collections import defaultdict, namedtuple
 from typing import List
 from functools import partial
+from pathlib import Path
 
 from .interpretable_drift import InterpretableDrift
 from ..constants import RANDOM_STATE
@@ -86,6 +87,7 @@ class DriftChecker(abc.ABC):
                              .columns)
 
         self.ml_discriminate_model = None
+        self.auc_discriminate_model = None
         self.drift = False
         self.interpretable_drift = None
 
@@ -93,7 +95,8 @@ class DriftChecker(abc.ABC):
                                   ml_discriminate_model: ScikitModel = None,
                                   column_names: List[str] = None,
                                   auc_threshold: float = .1,
-                                  new_target_column: str = 'is_left') -> bool:
+                                  new_target_column: str = 'is_left',
+                                  save_plot_path: Path = None) -> bool:
         """Creates a machine learning model based in `sklearn`,
         this model will be a classification model that will try
         to predict if a register is from `left_data` or `right_data`
@@ -161,9 +164,10 @@ class DriftChecker(abc.ABC):
 
         y_score = self.ml_discriminate_model.predict_proba(X_test)[:, 1]
 
-        auc_drift_check_model = roc_auc_score(y_true=y_test, y_score=y_score)
+        self.auc_discriminate_model = roc_auc_score(y_true=y_test,
+                                                    y_score=y_score)
 
-        self.drift = (symmetric_auc(auc_drift_check_model)
+        self.drift = (symmetric_auc(self.auc_discriminate_model)
                       < symmetric_auc(auc_threshold))
 
         self.interpretable_drift = InterpretableDrift(
@@ -177,9 +181,13 @@ class DriftChecker(abc.ABC):
         )
 
         if not self.minimal:
-            self.interpretable_drift.most_discriminative_features_plot()
+            self.interpretable_drift.most_discriminative_features_plot(
+                save_plot_path=save_plot_path
+            )
 
-        is_there_drift = symmetric_auc(auc_drift_check_model) > auc_threshold
+        is_there_drift = (
+                symmetric_auc(self.auc_discriminate_model) > auc_threshold
+        )
 
         if self.verbose:
             print(
@@ -190,7 +198,7 @@ class DriftChecker(abc.ABC):
                 end='\n\n'
             )
 
-            print(f'AUC drift check model: {auc_drift_check_model:.2f}')
+            print(f'AUC drift check model: {self.auc_discriminate_model:.2f}')
             print(f'AUC threshold: .5 ± {auc_threshold:.2f}')
 
         return is_there_drift
@@ -583,7 +591,8 @@ class ModelDriftChecker(DriftChecker):
 
         return is_there_drift
 
-    def show_feature_importance_vs_drift_map_plot(self, top: int = 10) -> None:
+    def show_feature_importance_vs_drift_map_plot(
+            self, top: int = 10, save_plot_path: Path = None) -> None:
         """Shows feature importance versus drift coefficient
         map
 
@@ -608,9 +617,11 @@ class ModelDriftChecker(DriftChecker):
             dict_each_column_drift_coefficient=(
                 data_drift_checker.dict_each_column_drift_coefficients
             ),
-            top=top))
+            top=top,
+            save_plot_path=save_plot_path))
 
-    def sample_weight_for_retrain(self) -> np.array:
+    def sample_weight_for_retrain(self,
+                                  save_plot_path: Path = None) -> np.array:
         """If you need to retrain your model maybe
         it's better applying this weights when you
         do it
@@ -645,7 +656,7 @@ class ModelDriftChecker(DriftChecker):
         if not self.minimal:
             (self
              .interpretable_drift
-             .weights_plot(weights))
+             .weights_plot(weights, save_plot_path=save_plot_path))
 
             print('Higher the weight for the observation, '
                   'more is it similar to the test data')
